@@ -14,7 +14,7 @@
   cat('\nhergm:', info[,"Title"], 
       '\nVersion', info[,"Version"], 'created on', info[,"Date"], '\n')   
   cat(paste("Copyright (c) 2009, Michael Schweinberger, Pennsylvania State University\n", sep = ""))
-  cat('Type help(package=\"hergm\") to start.\n\n')
+  cat('Type help(package=\"hergm\") to start.\n')
   }
 
 .Last.lib <- function(libpath)
